![icon.drawio.png](misc/artwork/icon_name.drawio.png)

-----------------------------------------------------------

## Description
Velocity is a tool to help with the maintenance of container build scripts on 
multiple systems, backends (e.g podman or apptainer) and distros.

## Documentation
See <https://olcf.github.io/velocity/>.

## Installation
``` commandline
pip install olcf-velocity
alias velocity="python3 -m velocity"
```
